@@ -132,7 +132,7 @@ SFCGAL_API void                      sfcgal_geometry_as_text( const sfcgal_geome
 /**
  * Returns a WKT representation of the given geometry using floating point coordinate values.
  * Floating point precision can be set via the numDecimals parameter.
- * Setting numDecimals to -1 yields the same result as sfcgal_geometry_as_text. 
+ * Setting numDecimals to -1 yields the same result as sfcgal_geometry_as_text.
  * @post buffer is returned allocated and must be freed by the caller
  * @ingroup capi
  */
@@ -782,6 +782,14 @@ SFCGAL_API sfcgal_geometry_t*          sfcgal_geometry_offset_polygon( const sfc
  */
 SFCGAL_API sfcgal_geometry_t*          sfcgal_geometry_straight_skeleton( const sfcgal_geometry_t* geom );
 
+/**
+ * Returns the approximate medial axis for the given Polygon
+ * Approximate medial axis is based on straight skeleton
+ * @pre isValid(geom) == true
+ * @ingroup capi
+ */
+SFCGAL_API sfcgal_geometry_t*          sfcgal_geometry_approximate_medial_axis( const sfcgal_geometry_t* geom );
+
 /*--------------------------------------------------------------------------------------*
  *
  * Error handling
